@@ -1,10 +1,8 @@
 {
   package Data::Pointer::IO;
-  $VERSION    = 0.1;
+  $VERSION    = 0.5;
   @ISA        = qw(Data::Pointer);
 
-  push @Data::Pointer::register, __PACKAGE__;
-
   use strict;
   use warnings;
 
@@ -21,19 +19,19 @@
   }
 
   sub _init {
-	my($class,$opts) = @_;
+    my($class,$opts) = @_;
 
     $opts->{_subtype} = exists $opts->{_subtype} ? $opts->{_subtype} : 'Line';
 
     my(@args) = $opts->{_value};
     push @args, rec_sep => \1
-		if Data::Pointer::i_eq($opts->{_subtype}, 'Char');
+        if Data::Pointer::i_eq($opts->{_subtype}, 'Char');
     
     $opts->{_value} = [];
     tie(@{ $opts->{_value} }, 'Tie::File', @args)
-		or Carp::croak("Couldn't tie file: $!");
+        or Carp::croak("Couldn't tie file: $!");
 
-	bless $opts, $class . '::' . ucfirst lc $opts->{_subtype};
+    bless $opts, $class . '::' . ucfirst lc $opts->{_subtype};
   }
 
   sub DESTROY {
@@ -46,8 +44,6 @@
   $VERSION    = 0.1;
   @ISA        = qw(Data::Pointer::IO);
 
-  push @Data::Pointer::register, __PACKAGE__;
-
   use strict;
   use warnings;
 
@@ -58,7 +54,7 @@
     my $val = [];
     if(@_ == 2 and Data::Pointer::_find_type($_[1]) eq 'IO' and *{$_[1]}{IO}) {
         tie(@$val, 'Tie::File', pop)
-			or Carp::croak("Couldn't tie file: $!");
+            or Carp::croak("Couldn't tie file: $!");
     } else {
         Carp::croak("Unknown IO type $_[1]");
     }
@@ -119,8 +115,6 @@
   $VERSION    = 0.1;
   @ISA        = qw(Data::Pointer::IO::Line);
 
-  push @Data::Pointer::register, __PACKAGE__;
-
   use strict;
   use warnings;
 
@@ -151,19 +145,19 @@ Data::Pointer::IO - The IO pointer type
 
 =head1 SYNOPSIS
 
-	use Data::Pointer qw(ptr);
+    use Data::Pointer qw(ptr);
   
-	open(my $fh, '<', 'somefile.txt') or die("ack - $!");
-	my $ptr = ptr( $fh );
+    open(my $fh, '<', 'somefile.txt') or die("ack - $!");
+    my $ptr = ptr( $fh );
 
-	print scalar $ptr->deref;      		  # first line of file
-	print $ptr->deref;                    # all of file
+    print scalar $ptr->deref;                # first line of file
+    print $ptr->deref;                    # all of file
   
-	open(my $fh, '>', 'somefile.txt') or die("ack - $!");
-	my $ptr = ptr( $fh );
+    open(my $fh, '>', 'somefile.txt') or die("ack - $!");
+    my $ptr = ptr( $fh );
 
-	$ptr->deref = "foo";                  # first line of somefile.txt
-	                                      # now equals 'foo'
+    $ptr->deref = "foo";                  # first line of somefile.txt
+                                          # now equals 'foo'
 
 =head1 DESCRIPTION
 
@@ -178,39 +172,39 @@ assignment should work in a similar way.
 =item assign($filehandle)
 
 Assign the pointer to a different value
-	
-	p = fopen('somefile', 'r')
+    
+    p = fopen('somefile', 'r')
 
 =item deref
 
 Dereference the pointer or assign to the value it's pointing to
-	
-	fgets(ret, SIZE_OF_$/, p)
-	fputs(val, p)
+    
+    fgets(ret, SIZE_OF_$/, p)
+    fputs(val, p)
 
 =item incr([$num])
 
 Increments the position of the pointer (default is 1)
-	
-	p++
+    
+    p++
 
 =item decr([$num])
 
 Decrements the position of the pointer (default is 1)
-	
-	p--
+    
+    p--
 
 =item plus($num)
 
 Return a pointer by the given offset
 
-	p + 1
+    p + 1
 
 =item minus($num)
 
 Return a pointer by the given offset
 
-	p - 1
+    p - 1
 
 =back
 
@@ -222,4 +216,10 @@ Dominus for the all singing, all dancing C<Tie::File>
 
 Dan Brook C<E<lt>broquaint@hotmail.comE<gt>>
 
+=head1 COPYRIGHT
+
+Copyright (c) 2002, Dan Brook. All Rights Reserved. This module is free
+software. It may be used, redistributed and/or modified under the same terms
+as Perl itself.
+
 =cut
